==> james-project-3.7.2-source-release.zip: james-project/server/container/guice/common/src/test/java/org/apache/james/utils/FailingPropertiesProvider.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.utils;

import java.io.FileNotFoundException;

import javax.inject.Inject;

import org.apache.commons.configuration2.PropertiesConfiguration;
import org.apache.commons.configuration2.ex.ConfigurationException;
import org.apache.james.filesystem.api.FileSystem;
import org.apache.james.server.core.configuration.Configuration;

public class FailingPropertiesProvider extends PropertiesProvider {

    @Inject
    public FailingPropertiesProvider(FileSystem fileSystem) throws FileNotFoundException {
        super(fileSystem, Configuration.builder()
            .workingDirectory(fileSystem.getBasedir().getAbsolutePath())
            .build()
            .configurationPath());
    }

    @Override
    public PropertiesConfiguration getConfiguration(String fileName) throws FileNotFoundException, ConfigurationException {
        throw new FileNotFoundException();
    }
}

==> james-project-3.9.0-source-release.zip: james-project/server/container/guice/common/src/test/java/org/apache/james/utils/FailingPropertiesProvider.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.utils;

import java.io.FileNotFoundException;

import jakarta.inject.Inject;

import org.apache.commons.configuration2.PropertiesConfiguration;
import org.apache.commons.configuration2.ex.ConfigurationException;
import org.apache.james.filesystem.api.FileSystem;
import org.apache.james.server.core.configuration.Configuration;

public class FailingPropertiesProvider extends PropertiesProvider {

    @Inject
    public FailingPropertiesProvider(FileSystem fileSystem) throws FileNotFoundException {
        super(fileSystem, Configuration.builder()
            .workingDirectory(fileSystem.getBasedir().getAbsolutePath())
            .build()
            .configurationPath());
    }

    @Override
    public PropertiesConfiguration getConfiguration(String fileName) throws FileNotFoundException, ConfigurationException {
        throw new FileNotFoundException();
    }
}
